pub unsafe fn handle_gpio_interrupt()Available on crate feature
unstable only.Expand description
Drives the GPIO async API from a user-installed raw GPIO interrupt handler.
Entry point for code that bypasses esp-hal’s GPIO ISR dispatch (typically
by defining a custom #[unsafe(no_mangle)] unsafe extern "C" fn GPIO(), or
by registering a handler via crate::interrupt::bind_handler) and needs
the GPIO async API to keep working.
Safety
Must be called from a GPIO interrupt context.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.